-- Version: 8.0 SP1 8.0.1.13

library ieee;
use ieee.std_logic_1164.all;
library Axcelerator;
use Axcelerator.all;

entity ddr_block is

    port( DSCLK        : out   std_logic;
          SO           : in    std_logic;
          OUT_RX_F     : out   std_logic;
          OUT_RX_R     : out   std_logic;
          CLEAR        : in    std_logic;
          TSELECT      : in    std_logic;
          STROBETX_REG : in    std_logic;
          DATATX_REG   : in    std_logic;
          RSELECT      : in    std_logic;
          RSTROBERX    : in    std_logic;
          RDATARX      : in    std_logic;
          PSELECT      : in    std_logic;
          PSTROBERX    : in    std_logic;
          PDATARX      : in    std_logic;
          \S[1]\       : in    std_logic
        );

end ddr_block;

architecture DEF_ARCH of ddr_block is 

  component MX4
    port( D0 : in    std_logic := 'U';
          D1 : in    std_logic := 'U';
          D2 : in    std_logic := 'U';
          D3 : in    std_logic := 'U';
          S0 : in    std_logic := 'U';
          S1 : in    std_logic := 'U';
          Y  : out   std_logic
        );
  end component;

  component DFC1B
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component DFC1D
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component XOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AND2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component CLKINT
    port( A : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component GND
    port(Y : out std_logic); 
  end component;

    signal \$1N11\, \$1N7\, \$1N9\, DATARX_F, DATARX_R, \DSCLK\, 
        \GND\, ORCLK, PDSCLKOUT, RDSCLKOUT, TDSCLKOUT, U10Q, U11Q, 
        U6Q, U7Q, U8Q, U9Q : std_logic;
    signal GND_power_net1 : std_logic;

begin 

    DSCLK <= \DSCLK\;
    \GND\ <= GND_power_net1;

    M2_F : MX4
      port map(D0 => U10Q, D1 => U8Q, D2 => U6Q, D3 => \GND\, S0
         => SO, S1 => \S[1]\, Y => DATARX_F);
    
    F1_R : DFC1B
      port map(D => DATARX_R, CLK => \DSCLK\, CLR => CLEAR, Q => 
        OUT_RX_R);
    
    U6 : DFC1D
      port map(D => DATATX_REG, CLK => \DSCLK\, CLR => CLEAR, Q
         => U6Q);
    
    X1P : XOR2
      port map(A => PDATARX, B => PSTROBERX, Y => \$1N7\);
    
    U9 : DFC1B
      port map(D => RDATARX, CLK => \DSCLK\, CLR => CLEAR, Q => 
        U9Q);
    
    A2R : AND2
      port map(A => \$1N9\, B => RSELECT, Y => RDSCLKOUT);
    
    A1P : AND2
      port map(A => \$1N7\, B => PSELECT, Y => PDSCLKOUT);
    
    RCLKBUF : CLKINT
      port map(A => ORCLK, Y => \DSCLK\);
    
    X2R : XOR2
      port map(A => RDATARX, B => RSTROBERX, Y => \$1N9\);
    
    U10 : DFC1D
      port map(D => PDATARX, CLK => \DSCLK\, CLR => CLEAR, Q => 
        U10Q);
    
    F2_F : DFC1B
      port map(D => DATARX_F, CLK => \DSCLK\, CLR => CLEAR, Q => 
        OUT_RX_F);
    
    U8 : DFC1D
      port map(D => RDATARX, CLK => \DSCLK\, CLR => CLEAR, Q => 
        U8Q);
    
    M1_R : MX4
      port map(D0 => U11Q, D1 => U9Q, D2 => U7Q, D3 => \GND\, S0
         => SO, S1 => \S[1]\, Y => DATARX_R);
    
    A3T : AND2
      port map(A => \$1N11\, B => TSELECT, Y => TDSCLKOUT);
    
    X3T : XOR2
      port map(A => DATATX_REG, B => STROBETX_REG, Y => \$1N11\);
    
    O1 : OR3
      port map(A => RDSCLKOUT, B => PDSCLKOUT, C => TDSCLKOUT, Y
         => ORCLK);
    
    U11 : DFC1B
      port map(D => PDATARX, CLK => \DSCLK\, CLR => CLEAR, Q => 
        U11Q);
    
    U7 : DFC1B
      port map(D => DATATX_REG, CLK => \DSCLK\, CLR => CLEAR, Q
         => U7Q);
    
    GND_power_inst1 : GND
      port map( Y => GND_power_net1);


end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library Axcelerator;
use Axcelerator.all;

entity SPACEWIRE_1PORT_TOP is

    port( RDATARX1P   : in    std_logic;
          RDATARX1N   : in    std_logic;
          RSTROBERX1N : in    std_logic;
          PDATARX1N   : in    std_logic;
          PDATARX1P   : in    std_logic;
          PSTROBERX1P : in    std_logic;
          RSTROBERX1P : in    std_logic;
          DSCLK       : out   std_logic;
          RSELECT     : in    std_logic;
          PSELECT     : in    std_logic;
          STROBETX    : in    std_logic;
          DATATX      : in    std_logic;
          TSELECT     : in    std_logic;
          SAMPLECLK   : in    std_logic;
          RESET       : in    std_logic;
          OUT_RX_F    : out   std_logic;
          OUT_RX_R    : out   std_logic;
          SI          : in    std_logic;
          SO          : in    std_logic;
          PSTROBERX1N : in    std_logic
        );

end SPACEWIRE_1PORT_TOP;

architecture DEF_ARCH of SPACEWIRE_1PORT_TOP is 

  component DFC1B
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component INBUF
    port( PAD : in    std_logic := 'U';
          Y   : out   std_logic
        );
  end component;

  component ddr_block
    port( DSCLK        : out   std_logic;
          SO           : in    std_logic := 'U';
          OUT_RX_F     : out   std_logic;
          OUT_RX_R     : out   std_logic;
          CLEAR        : in    std_logic := 'U';
          TSELECT      : in    std_logic := 'U';
          STROBETX_REG : in    std_logic := 'U';
          DATATX_REG   : in    std_logic := 'U';
          RSELECT      : in    std_logic := 'U';
          RSTROBERX    : in    std_logic := 'U';
          RDATARX      : in    std_logic := 'U';
          PSELECT      : in    std_logic := 'U';
          PSTROBERX    : in    std_logic := 'U';
          PDATARX      : in    std_logic := 'U';
          \S[1]\       : in    std_logic := 'U'
        );
  end component;

  component INBUF_LVDS
    port( PADP : in    std_logic := 'U';
          PADN : in    std_logic := 'U';
          Y    : out   std_logic
        );
  end component;

  component OUTBUF
    port( D   : in    std_logic := 'U';
          PAD : out   std_logic
        );
  end component;

  component HCLKBUF
    port( PAD : in    std_logic := 'U';
          Y   : out   std_logic
        );
  end component;

    signal \$1N101\, \$1N103\, \$1N105\, \$1N111\, \$1N198\, 
        \$1N355\, \$1N99\, NS01, S1_DATATX_REG, S1_PSELECT_REG, 
        S1_RSELECT_REG, S1_STROBETX_REG, S1_TSELECT_REG, 
        \NDSCLK[1]\, \NPD[1]\, \NPS[1]\, \NRD[1]\, \NRS[1]\, 
        \NRXF[1]\, \NRXR[1]\, \NS[11]\ : std_logic;

begin 


    S1_U15 : DFC1B
      port map(D => \$1N101\, CLK => \$1N111\, CLR => \$1N355\, Q
         => S1_STROBETX_REG);
    
    S1_U12 : DFC1B
      port map(D => \$1N198\, CLK => \$1N111\, CLR => \$1N355\, Q
         => S1_PSELECT_REG);
    
    \$1I265\ : INBUF
      port map(PAD => SO, Y => NS01);
    
    SPACEWIRE1 : ddr_block
      port map(DSCLK => \NDSCLK[1]\, SO => NS01, OUT_RX_F => 
        \NRXF[1]\, OUT_RX_R => \NRXR[1]\, CLEAR => \$1N355\, 
        TSELECT => S1_TSELECT_REG, STROBETX_REG => 
        S1_STROBETX_REG, DATATX_REG => S1_DATATX_REG, RSELECT => 
        S1_RSELECT_REG, RSTROBERX => \NRS[1]\, RDATARX => 
        \NRD[1]\, PSELECT => S1_PSELECT_REG, PSTROBERX => 
        \NPS[1]\, PDATARX => \NPD[1]\, \S[1]\ => \NS[11]\);
    
    \$1I359\ : INBUF_LVDS
      port map(PADP => RDATARX1P, PADN => RDATARX1N, Y => 
        \NRD[1]\);
    
    \$1I348\ : INBUF
      port map(PAD => RESET, Y => \$1N355\);
    
    \$1I192\ : INBUF
      port map(PAD => TSELECT, Y => \$1N99\);
    
    \$1I234\ : OUTBUF
      port map(D => \NDSCLK[1]\, PAD => DSCLK);
    
    S1_U13 : DFC1B
      port map(D => \$1N105\, CLK => \$1N111\, CLR => \$1N355\, Q
         => S1_RSELECT_REG);
    
    \$1I344\ : HCLKBUF
      port map(PAD => SAMPLECLK, Y => \$1N111\);
    
    \$1I183\ : INBUF
      port map(PAD => PSELECT, Y => \$1N198\);
    
    \$1I175\ : INBUF
      port map(PAD => RSELECT, Y => \$1N105\);
    
    S1_U16 : DFC1B
      port map(D => \$1N99\, CLK => \$1N111\, CLR => \$1N355\, Q
         => S1_TSELECT_REG);
    
    \$1I267\ : INBUF
      port map(PAD => SI, Y => \NS[11]\);
    
    \$1I357\ : INBUF_LVDS
      port map(PADP => PDATARX1P, PADN => PDATARX1N, Y => 
        \NPD[1]\);
    
    \$1I189\ : INBUF
      port map(PAD => STROBETX, Y => \$1N101\);
    
    S1_U14 : DFC1B
      port map(D => \$1N103\, CLK => \$1N111\, CLR => \$1N355\, Q
         => S1_DATATX_REG);
    
    \$1I356\ : INBUF_LVDS
      port map(PADP => PSTROBERX1P, PADN => PSTROBERX1N, Y => 
        \NPS[1]\);
    
    \$1I186\ : INBUF
      port map(PAD => DATATX, Y => \$1N103\);
    
    \$1I235\ : OUTBUF
      port map(D => \NRXF[1]\, PAD => OUT_RX_F);
    
    \$1I358\ : INBUF_LVDS
      port map(PADP => RSTROBERX1P, PADN => RSTROBERX1N, Y => 
        \NRS[1]\);
    
    \$1I236\ : OUTBUF
      port map(D => \NRXR[1]\, PAD => OUT_RX_R);
    

end DEF_ARCH; 
